/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Jaroslav Tulach
 */

package cz.xelfi.quoridor;

import cz.xelfi.quoridor.Fence.Orientation;
import cz.xelfi.quoridor.Player.Direction;
import org.junit.Test;
import static org.junit.Assert.*;

/**
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
public class MoveTest {

    public MoveTest() {
    }

    @Test
    public void testNorth() throws Exception {
        checkValueOf("N", Move.NORTH);
    }
    @Test
    public void testSouth() throws Exception {
        checkValueOf("S", Move.SOUTH);
    }
    @Test
    public void testEast() throws Exception {
        checkValueOf("E", Move.EAST);
    }
    @Test
    public void testWest() throws Exception {
        checkValueOf("W", Move.WEST);
    }
    @Test
    public void testRegisn() throws Exception {
        checkValueOf("RESIGN", Move.RESIGN);
    }
    @Test
    public void testJumps() throws Exception {
        for (Direction d1 : Direction.values()) {
            for (Direction d2 : Direction.values()) {
                checkValueOf("" + d1.name().charAt(0) + d2.name().charAt(0), Move.jump(d1, d2));
            }
        }
    }
    @Test
    public void testFences() throws Exception {
        for (int i = 1; i <= 8; i++) {
            for (int j = 0; i < 8; i++) {
                String h = "H" + (char)('A'+ j) + i;
                String v = "V" + (char)('A'+ j) + i;

                Move hm = Move.fence((char) ('A' + j), i, Orientation.HORIZONTAL);
                Move vm = Move.fence((char) ('A' + j), i, Orientation.VERTICAL);

                checkValueOf(h, hm);
                checkValueOf(v, vm);
            }
        }
    }

    private static void checkValueOf(String txt, Move move) throws Exception {
        assertEquals("toString", txt, move.toString());
        assertEquals("valueOf", move, Move.valueOf(txt));
    }

}